<?php

namespace App\Http\Controllers;
use App\Models\User;
use Illuminate\Support\Facades\Hash;
use Illuminate\Http\Request;
use App\Http\Middleware\Userauth;


class Agentcontrooler extends Controller
{

    public function __construct()
    {
        $this->middleware(Userauth::class);
    }
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $user = User::where('user_type',0)->get();
        return view('admin/agents/index', compact('user'));
    }

    public function create()
    {
        return view('admin/agents/create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $request->validate([
            'agent_name' => 'required',
            'email' => 'required|email|unique:users',
            'password' => 'required|min:8',
            'confirm_password' => 'required_with:password|same:password|min:8',
            'mobile' => 'required|min:10',
        ]);
        $user = User::create([
            'name' => $request->agent_name,
            'email' => $request->email,
            'mobile' => $request->mobile,
            'address' => $request->address,
            'password' => Hash::make($request->password),
        ]);
        return redirect()->back()->withSuccess('User created !!!');
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {

    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $user = User::find($id);
        if($user !== null){
            return view('admin.agents.edit', ['user' => $user]);
        }else{
            return redirect('agents')->with('error', 'Agent Not Found');
        }
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $user = User::find($id);
        if($request->passowrd !== null &&  $request->confirm_passowrd !== null){
            $request->validate([
                'agent_name' => 'required',
                'email' => 'required',
                'password' => 'required|min:8',
                'confirm_password' => 'required_with:password|same:password|min:8',
                'mobile' => 'required|min:10',
            ]);
            $data = [
                'name' => $request->agent_name,
                'email' => $request->email,
                'mobile' => $request->mobile,
                'address' => $request->address,
                'password' => bcrypt($request->password),
            ];
        }else{
            $request->validate([
                'agent_name' => 'required',
                'email' => 'required',
                'mobile' => 'required|min:10',
            ]);
            $data = [
                'name' => $request->agent_name,
                'email' => $request->email,
                'mobile' => $request->mobile,
                'address' => $request->address,
            ];
        }
        $user = User::where('id', $id)->update($data);
        return redirect('agents')->withSuccess('Agent Updated');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        // $user = User::find($id);
        // if($user !== null){
        //     if($user->status == 1){
        //         $change['status'] = 0;
        //         $status = 'Deactiveted';
        //     }else{
        //         $change['status'] = 1;
        //         $status = 'Activaste';
        //     }
        //     $user->update($change);
        //     return redirect()->back()->withSuccess('Agent '.$status);
        // }else{
        //     return redirect('agents')->with('error', 'Agent Not Found');
        // }
        $user = User::find($id);
        if($user !== null){
            $user->delete();
            return redirect()->back()->withSuccess('Agent Deleted');
        }else{
            return redirect('agents')->with('error', 'Agent Not Found');
        }
    }
}
