<?php

namespace App\Http\Controllers;

use App\Models\User;
use App\Models\Status;
use App\Models\Lead;
use App\Models\Project;
use App\Models\Comment;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;
use League\CommonMark\Extension\CommonMark\Node\Inline\Strong;

class LeadsController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $leads = DB::table('leads')
        ->orderBy('leads.id', 'desc')
            ->leftJoin('tbl_cities', 'tbl_cities.city_id', 'leads.city')
            ->leftJoin('tbl_states', 'tbl_states.state_id', 'leads.state')
            ->leftJoin('projects', 'projects.id', 'leads.project')
            ->leftJoin('users', 'users.id', 'leads.created_by')
            ->select('leads.*', 'tbl_cities.city_name', 'tbl_states.state', 'projects.project_name', 'users.name')
            //->where('leads.created_by', Auth::user()->id)
            ->get();
        $status = Status::all();
        return view('admin/leads/index', compact('leads', 'status'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $agent = User::all();
        $project = Project::all();
        $country = DB::table('countries')->orderBy('name', 'asc')->get();
        $status = Status::all();
        return view('admin/leads/create', compact('country', 'status', 'agent', 'project'));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    { 
        $data = $request->validate([
            'project' => 'required',
            'customer_name' => 'required',
            // 'company_name' => 'required',
            // 'email' => 'required',
            'mobile' => 'required|unique:leads,mobile',
            'follow_up' => 'required',
            'follow_up_time' => 'required',
            'Q_S_Name' => 'required',
            'feedback' => 'required',
            'current_status' => 'required',  
        ]);

        if($request->company_name !== null){
            $data['company_name'] = $request->company_name;
        }
        if($request->email !== null){
            $data['email'] = $request->email;
        }
        if($request->reference !== null){
            $data['reference'] = $request->reference;
        }
        if($request->country !== null){
            $data['country'] = $request->country;
        }

        if($request->state !== null){
            $data['state'] = $request->state;
        }

        if($request->city !== null){
            $data['city'] = $request->city;
        }
        if(Auth::user()->user_type == 1){
            $data['created_by'] = $request->Q_S_Name;
        }else{
            $data['created_by'] = Auth::user()->id;
        }
        if($request->alternet_mobile !== null){
            $data['alternet_mobile'] = $request->alternet_mobile;
        }
        if (Lead::create($data)) {
            return redirect('leads')->with('success', 'Lead Created Successfully');
        } else {
            return back()->with('error', 'Please try later');
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(Request $request, $id)
    {    
        $leads = lead::find($id);
        $lead_data = DB::table('leads')
            ->where('leads.id', $id)
            ->leftJoin('countries', 'countries.id', 'leads.country')
            ->leftJoin('tbl_cities', 'tbl_cities.city_id', 'leads.city')
            ->leftJoin('tbl_states', 'tbl_states.state_id', 'leads.state')
            ->leftJoin('projects', 'projects.id', 'leads.project')
            ->leftJoin('users', 'users.id', 'leads.Q_S_Name')
            ->select('leads.*', 'tbl_cities.city_name', 'countries.name as country_name', 'tbl_states.state', 'projects.project_name', 'users.name')
            ->first(); 
        // dd($lead_data);


        if($request->notify !== null){
            $leads->notify = 0;
            $leads->update();
        }
        $comments = Comment::where('lead_id', $id)
            ->orderBy('id', 'DESC')
            ->get(); 
        $status = Status::all();
        return view('admin/leads/show', compact('lead_data', 'comments', 'status'));
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $lead = Lead::findorfail($id);
        $agent = User::all();
        $project = Project::all();
        $states = DB::table('tbl_states')->get();
        $status = Status::all();

        $country = DB::table('countries')->orderBy('name','asc')->get();
        // $state = DB::table('tbl_states')->where('id',$lead->state)->first();
        // $citie = DB::table('tbl_cities')->where('city_id',$lead->city)->first();
        return view('admin/leads/edit', compact('lead', 'country', 'status', 'agent', 'project'));
    } 

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    { 
        $lead = Lead::find($id); 
        $lead->project =  $request->get('project');
        $lead->customer_name = $request->get('customer_name');
        $lead->company_name = $request->get('company_name');
        $lead->email = $request->get('email');
        $lead->mobile = $request->get('mobile'); 
        $lead->follow_up = $request->get('follow_up');
        $lead->follow_up_time = $request->get('follow_up_time');
        
        if (Auth::user()->user_type == 1) {
            $lead->Q_S_Name = $request->get('Q_S_Name');
        } else {
            $lead->Q_S_Name = Auth::user()->id;
        }

        $lead->feedback = $request->get('feedback');
        $lead->current_status = $request->get('current_status');
        $lead->alternet_mobile = $request->get('alternet_mobile');
        // if(strtotime($request->get('follow_up')) >= strtotime(date('Y-m-d'))) {
        //     $lead->notify = 1;
        // }else{
        //     $lead->notify = 0;
        // }
        $lead->notify = 1;

        if($request->reference !== null){
            $lead->reference = $request->reference;
        }
        if($request->country !== null){
            $lead->country = $request->country;
        }

        if($request->state !== null){
            $lead->state = $request->state;
        }

        if($request->city !== null){
            $lead->city = $request->city;
        } 
        $lead->update();
        return redirect('leads')->with('success', 'Lead Updated');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy($id)
    {
        Lead::find($id)->delete();
        session()->flash('success', ' Lead Deleted Successfully.');
        return back();
    }


    public function change_status(Request $request)
    {
        $id = $request->id;
        $status = $request->status;
        $content = Lead::findOrFail($id);
        $content->current_status = $status;
        $content->save();
    }


    public function agents_lead()
    {
        $leads = lead::all();
        return view('user.lead', compact('leads'));
    }

    public function print($id)
    {
        $lead_data = DB::table('leads')
            ->where('leads.id', $id)
            ->leftJoin('countries', 'countries.id', 'leads.country')
            ->leftJoin('tbl_cities', 'tbl_cities.city_id', 'leads.city')
            ->leftJoin('tbl_states', 'tbl_states.state_id', 'leads.state')
            ->leftJoin('projects', 'projects.id', 'leads.project')
            ->leftJoin('users', 'users.id', 'leads.Q_S_Name')
            ->select('leads.*', 'tbl_cities.city_name', 'countries.name as country_name', 'tbl_states.state', 'projects.project_name', 'users.name')
            ->first();
 
        $comments = Comment::where('lead_id', $id)
            ->orderBy('id', 'DESC')
            ->get();

        // dd($comments);
        $status = Status::all();
        return view('admin/leads/printr', compact('lead_data', 'comments', 'status'));
    }

    public function check_mobile(Request $request){
        $mobile = $request->mobile;
        if(Lead::where('mobile', $mobile)->first() !== null){
            $status = 0;
        }else{
            $status = 1;
        }
        return $status;
    }

    public function notifications(){
        $lead_where = [
            'notify' => 1,
            'Q_S_Name'=>Auth::user()->id,
        ];
        $data['leads'] = Lead::where($lead_where)->where('follow_up','<=',date('Y-m-d'))->get(); 
        return view('admin/notify/notification', ['title'=>config('app.Site_name'). ' | Notification'], $data);
    }

    
    public function notify_update_form(string $id)
    {
        $lead = Lead::findorfail($id);
        $agent = User::all();
        $project = Project::all();
        $states = DB::table('tbl_states')->get();
        $status = Status::all();

        $country = DB::table('countries')->orderBy('name','asc')->get(); 
        return view('admin/notify/edit', compact('lead', 'country', 'status', 'agent', 'project'));
    }

public function notify_close($id){
    $lead = Lead::find($id); 
    $lead->notify = 0;
    $lead->update();
    return redirect()->back();
}

public function notify_update_submit(Request $request, string $id)
{ 
        $lead = Lead::find($id); 
        $lead->project =  $request->get('project');
        $lead->customer_name = $request->get('customer_name');
        $lead->company_name = $request->get('company_name');
        $lead->email = $request->get('email');
        $lead->mobile = $request->get('mobile'); 
        $lead->follow_up = $request->get('follow_up');
        $lead->follow_up_time = $request->get('follow_up_time');
        $lead->Q_S_Name = Auth::user()->id;
        
        if (Auth::user()->user_type == 1) {
            $lead->Q_S_Name = $request->get('Q_S_Name');
        } else {
            $lead->Q_S_Name = Auth::user()->id;
        }

        $lead->feedback = $request->get('feedback');
        $lead->current_status = $request->get('current_status');
        $lead->alternet_mobile = $request->get('alternet_mobile');
        // if(strtotime($request->get('follow_up')) >= strtotime(date('Y-m-d'))){
        //     $lead->notify = 1;
        // }else{
        //     $lead->notify = 0;
        // }
        $lead->notify = 1;

        if($request->reference !== null){
            $lead->reference = $request->reference;
        }
        if($request->country !== null){
            $lead->country = $request->country;
        }

        if($request->state !== null){
            $lead->state = $request->state;
        }

        if($request->city !== null){
            $lead->city = $request->city;
        } 
        $lead->update();
        return redirect('lead-notifications')->with('success', 'Lead Updated');
    }

}
