<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Project;
use Illuminate\Support\Facades\DB;

class ProjectsController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $all_projects = Project::all();
        return view('admin/projects/index', compact('all_projects'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin/projects/create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    { 
        $data = $request->validate([
            'project_name' => 'required|unique:projects,project_name'
        ]);
        if(Project::create($data)){
            return redirect('projects')->with('success', 'Project Created Successfully');
        }else{
            return back()->with('error', 'Please try later');
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $data = Project::findorfail($id);
        return view('admin/projects/edit', compact('data'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $validate = $request->validate([
            'project_name' => 'required|unique:projects,project_name'
        ]);
        $data = Project::findorfail($id);
        $check = Project::where('project_name',$validate['project_name'])
            ->where('id','!=',$id)
            ->first(); 
        if($check == null){
            DB::table('projects')->where('id',$id)->update($validate);
            return redirect('projects')->with('success', 'Projects Name Updated'); 
        }else{
            return back()->with('error', 'Project name already exist');
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
       $find = Project::find($id);
        if($find !== null){
            if(DB::table('leads')->where('project',$find->id)->first() !== null){
                return redirect()->back()->with('error', "Can't Delete Project Because It's Used In Leads");
            }else{
                $find->delete();
                return redirect()->back()->with('success', 'Project Deleted Successfully.');
            }
        }else{
            return redirect()->back()->with('error', 'Project Deleted Successfully.');
        }
    }
}
